"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
from documenso_sdk.models import DocumensoError
from documenso_sdk.types import BaseModel, Nullable, UNSET_SENTINEL
from enum import Enum
import httpx
import pydantic
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class FolderCreateFolderTypeRequest(str, Enum):
    DOCUMENT = "DOCUMENT"
    TEMPLATE = "TEMPLATE"


class FolderCreateFolderRequestTypedDict(TypedDict):
    name: str
    parent_id: NotRequired[str]
    type: NotRequired[FolderCreateFolderTypeRequest]


class FolderCreateFolderRequest(BaseModel):
    name: str

    parent_id: Annotated[Optional[str], pydantic.Field(alias="parentId")] = None

    type: Optional[FolderCreateFolderTypeRequest] = None


class FolderCreateFolderInternalServerErrorIssueTypedDict(TypedDict):
    message: str


class FolderCreateFolderInternalServerErrorIssue(BaseModel):
    message: str


class FolderCreateFolderInternalServerErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[FolderCreateFolderInternalServerErrorIssue]] = None


@dataclass(unsafe_hash=True)
class FolderCreateFolderInternalServerError(DocumensoError):
    r"""Internal server error"""

    data: FolderCreateFolderInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: FolderCreateFolderInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class FolderCreateFolderForbiddenIssueTypedDict(TypedDict):
    message: str


class FolderCreateFolderForbiddenIssue(BaseModel):
    message: str


class FolderCreateFolderForbiddenErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[FolderCreateFolderForbiddenIssue]] = None


@dataclass(unsafe_hash=True)
class FolderCreateFolderForbiddenError(DocumensoError):
    r"""Insufficient access"""

    data: FolderCreateFolderForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: FolderCreateFolderForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class FolderCreateFolderUnauthorizedIssueTypedDict(TypedDict):
    message: str


class FolderCreateFolderUnauthorizedIssue(BaseModel):
    message: str


class FolderCreateFolderUnauthorizedErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[FolderCreateFolderUnauthorizedIssue]] = None


@dataclass(unsafe_hash=True)
class FolderCreateFolderUnauthorizedError(DocumensoError):
    r"""Authorization not provided"""

    data: FolderCreateFolderUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: FolderCreateFolderUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class FolderCreateFolderBadRequestIssueTypedDict(TypedDict):
    message: str


class FolderCreateFolderBadRequestIssue(BaseModel):
    message: str


class FolderCreateFolderBadRequestErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[FolderCreateFolderBadRequestIssue]] = None


@dataclass(unsafe_hash=True)
class FolderCreateFolderBadRequestError(DocumensoError):
    r"""Invalid input data"""

    data: FolderCreateFolderBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: FolderCreateFolderBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class FolderCreateFolderVisibility(str, Enum):
    EVERYONE = "EVERYONE"
    MANAGER_AND_ABOVE = "MANAGER_AND_ABOVE"
    ADMIN = "ADMIN"


class FolderCreateFolderTypeResponse(str, Enum):
    DOCUMENT = "DOCUMENT"
    TEMPLATE = "TEMPLATE"


class FolderCreateFolderResponseTypedDict(TypedDict):
    r"""Successful response"""

    id: str
    name: str
    user_id: float
    team_id: float
    parent_id: Nullable[str]
    pinned: bool
    created_at: str
    updated_at: str
    visibility: FolderCreateFolderVisibility
    type: FolderCreateFolderTypeResponse


class FolderCreateFolderResponse(BaseModel):
    r"""Successful response"""

    id: str

    name: str

    user_id: Annotated[float, pydantic.Field(alias="userId")]

    team_id: Annotated[float, pydantic.Field(alias="teamId")]

    parent_id: Annotated[Nullable[str], pydantic.Field(alias="parentId")]

    pinned: bool

    created_at: Annotated[str, pydantic.Field(alias="createdAt")]

    updated_at: Annotated[str, pydantic.Field(alias="updatedAt")]

    visibility: FolderCreateFolderVisibility

    type: FolderCreateFolderTypeResponse

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = ["parentId"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
from documenso_sdk.models import DocumensoError
from documenso_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from documenso_sdk.utils import FieldMetadata, PathParamMetadata
from enum import Enum
import httpx
import pydantic
from pydantic import model_serializer
from typing import Any, List, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


class FieldGetTemplateFieldRequestTypedDict(TypedDict):
    field_id: float


class FieldGetTemplateFieldRequest(BaseModel):
    field_id: Annotated[
        float,
        pydantic.Field(alias="fieldId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]


class FieldGetTemplateFieldInternalServerErrorIssueTypedDict(TypedDict):
    message: str


class FieldGetTemplateFieldInternalServerErrorIssue(BaseModel):
    message: str


class FieldGetTemplateFieldInternalServerErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[FieldGetTemplateFieldInternalServerErrorIssue]] = None


@dataclass(unsafe_hash=True)
class FieldGetTemplateFieldInternalServerError(DocumensoError):
    r"""Internal server error"""

    data: FieldGetTemplateFieldInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: FieldGetTemplateFieldInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class FieldGetTemplateFieldNotFoundIssueTypedDict(TypedDict):
    message: str


class FieldGetTemplateFieldNotFoundIssue(BaseModel):
    message: str


class FieldGetTemplateFieldNotFoundErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[FieldGetTemplateFieldNotFoundIssue]] = None


@dataclass(unsafe_hash=True)
class FieldGetTemplateFieldNotFoundError(DocumensoError):
    r"""Not found"""

    data: FieldGetTemplateFieldNotFoundErrorData = field(hash=False)

    def __init__(
        self,
        data: FieldGetTemplateFieldNotFoundErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class FieldGetTemplateFieldForbiddenIssueTypedDict(TypedDict):
    message: str


class FieldGetTemplateFieldForbiddenIssue(BaseModel):
    message: str


class FieldGetTemplateFieldForbiddenErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[FieldGetTemplateFieldForbiddenIssue]] = None


@dataclass(unsafe_hash=True)
class FieldGetTemplateFieldForbiddenError(DocumensoError):
    r"""Insufficient access"""

    data: FieldGetTemplateFieldForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: FieldGetTemplateFieldForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class FieldGetTemplateFieldUnauthorizedIssueTypedDict(TypedDict):
    message: str


class FieldGetTemplateFieldUnauthorizedIssue(BaseModel):
    message: str


class FieldGetTemplateFieldUnauthorizedErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[FieldGetTemplateFieldUnauthorizedIssue]] = None


@dataclass(unsafe_hash=True)
class FieldGetTemplateFieldUnauthorizedError(DocumensoError):
    r"""Authorization not provided"""

    data: FieldGetTemplateFieldUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: FieldGetTemplateFieldUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class FieldGetTemplateFieldBadRequestIssueTypedDict(TypedDict):
    message: str


class FieldGetTemplateFieldBadRequestIssue(BaseModel):
    message: str


class FieldGetTemplateFieldBadRequestErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[FieldGetTemplateFieldBadRequestIssue]] = None


@dataclass(unsafe_hash=True)
class FieldGetTemplateFieldBadRequestError(DocumensoError):
    r"""Invalid input data"""

    data: FieldGetTemplateFieldBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: FieldGetTemplateFieldBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class FieldGetTemplateFieldType(str, Enum):
    SIGNATURE = "SIGNATURE"
    FREE_SIGNATURE = "FREE_SIGNATURE"
    INITIALS = "INITIALS"
    NAME = "NAME"
    EMAIL = "EMAIL"
    DATE = "DATE"
    TEXT = "TEXT"
    NUMBER = "NUMBER"
    RADIO = "RADIO"
    CHECKBOX = "CHECKBOX"
    DROPDOWN = "DROPDOWN"


class FieldGetTemplateFieldTypeDropdown(str, Enum):
    DROPDOWN = "dropdown"


class FieldGetTemplateFieldValue3TypedDict(TypedDict):
    value: str


class FieldGetTemplateFieldValue3(BaseModel):
    value: str


class FieldGetTemplateFieldFieldMetaDropdownTypedDict(TypedDict):
    type: FieldGetTemplateFieldTypeDropdown
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    values: NotRequired[List[FieldGetTemplateFieldValue3TypedDict]]
    default_value: NotRequired[str]


class FieldGetTemplateFieldFieldMetaDropdown(BaseModel):
    type: FieldGetTemplateFieldTypeDropdown

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    values: Optional[List[FieldGetTemplateFieldValue3]] = None

    default_value: Annotated[Optional[str], pydantic.Field(alias="defaultValue")] = None


class FieldGetTemplateFieldTypeCheckbox(str, Enum):
    CHECKBOX = "checkbox"


class FieldGetTemplateFieldValue2TypedDict(TypedDict):
    id: float
    checked: bool
    value: str


class FieldGetTemplateFieldValue2(BaseModel):
    id: float

    checked: bool

    value: str


class FieldGetTemplateFieldDirection2(str, Enum):
    VERTICAL = "vertical"
    HORIZONTAL = "horizontal"


class FieldGetTemplateFieldFieldMetaCheckboxTypedDict(TypedDict):
    type: FieldGetTemplateFieldTypeCheckbox
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    values: NotRequired[List[FieldGetTemplateFieldValue2TypedDict]]
    validation_rule: NotRequired[str]
    validation_length: NotRequired[float]
    direction: NotRequired[FieldGetTemplateFieldDirection2]


class FieldGetTemplateFieldFieldMetaCheckbox(BaseModel):
    type: FieldGetTemplateFieldTypeCheckbox

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    values: Optional[List[FieldGetTemplateFieldValue2]] = None

    validation_rule: Annotated[
        Optional[str], pydantic.Field(alias="validationRule")
    ] = None

    validation_length: Annotated[
        Optional[float], pydantic.Field(alias="validationLength")
    ] = None

    direction: Optional[FieldGetTemplateFieldDirection2] = (
        FieldGetTemplateFieldDirection2.VERTICAL
    )


class FieldGetTemplateFieldTypeRadio(str, Enum):
    RADIO = "radio"


class FieldGetTemplateFieldValue1TypedDict(TypedDict):
    id: float
    checked: bool
    value: str


class FieldGetTemplateFieldValue1(BaseModel):
    id: float

    checked: bool

    value: str


class FieldGetTemplateFieldDirection1(str, Enum):
    VERTICAL = "vertical"
    HORIZONTAL = "horizontal"


class FieldGetTemplateFieldFieldMetaRadioTypedDict(TypedDict):
    type: FieldGetTemplateFieldTypeRadio
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    values: NotRequired[List[FieldGetTemplateFieldValue1TypedDict]]
    direction: NotRequired[FieldGetTemplateFieldDirection1]


class FieldGetTemplateFieldFieldMetaRadio(BaseModel):
    type: FieldGetTemplateFieldTypeRadio

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    values: Optional[List[FieldGetTemplateFieldValue1]] = None

    direction: Optional[FieldGetTemplateFieldDirection1] = (
        FieldGetTemplateFieldDirection1.VERTICAL
    )


class FieldGetTemplateFieldTypeNumber(str, Enum):
    NUMBER = "number"


class FieldGetTemplateFieldTextAlign6(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class FieldGetTemplateFieldVerticalAlign2(str, Enum):
    TOP = "top"
    MIDDLE = "middle"
    BOTTOM = "bottom"


class FieldGetTemplateFieldFieldMetaNumberTypedDict(TypedDict):
    type: FieldGetTemplateFieldTypeNumber
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    number_format: NotRequired[Nullable[str]]
    value: NotRequired[str]
    min_value: NotRequired[Nullable[float]]
    max_value: NotRequired[Nullable[float]]
    text_align: NotRequired[FieldGetTemplateFieldTextAlign6]
    line_height: NotRequired[Nullable[float]]
    letter_spacing: NotRequired[Nullable[float]]
    vertical_align: NotRequired[Nullable[FieldGetTemplateFieldVerticalAlign2]]


class FieldGetTemplateFieldFieldMetaNumber(BaseModel):
    type: FieldGetTemplateFieldTypeNumber

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    number_format: Annotated[
        OptionalNullable[str], pydantic.Field(alias="numberFormat")
    ] = UNSET

    value: Optional[str] = None

    min_value: Annotated[OptionalNullable[float], pydantic.Field(alias="minValue")] = (
        UNSET
    )

    max_value: Annotated[OptionalNullable[float], pydantic.Field(alias="maxValue")] = (
        UNSET
    )

    text_align: Annotated[
        Optional[FieldGetTemplateFieldTextAlign6], pydantic.Field(alias="textAlign")
    ] = None

    line_height: Annotated[
        OptionalNullable[float], pydantic.Field(alias="lineHeight")
    ] = UNSET

    letter_spacing: Annotated[
        OptionalNullable[float], pydantic.Field(alias="letterSpacing")
    ] = UNSET

    vertical_align: Annotated[
        OptionalNullable[FieldGetTemplateFieldVerticalAlign2],
        pydantic.Field(alias="verticalAlign"),
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "label",
            "placeholder",
            "required",
            "readOnly",
            "fontSize",
            "numberFormat",
            "value",
            "minValue",
            "maxValue",
            "textAlign",
            "lineHeight",
            "letterSpacing",
            "verticalAlign",
        ]
        nullable_fields = [
            "numberFormat",
            "minValue",
            "maxValue",
            "lineHeight",
            "letterSpacing",
            "verticalAlign",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class FieldGetTemplateFieldTypeText(str, Enum):
    TEXT = "text"


class FieldGetTemplateFieldTextAlign5(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class FieldGetTemplateFieldVerticalAlign1(str, Enum):
    TOP = "top"
    MIDDLE = "middle"
    BOTTOM = "bottom"


class FieldGetTemplateFieldFieldMetaTextTypedDict(TypedDict):
    type: FieldGetTemplateFieldTypeText
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text: NotRequired[str]
    character_limit: NotRequired[float]
    text_align: NotRequired[FieldGetTemplateFieldTextAlign5]
    line_height: NotRequired[Nullable[float]]
    letter_spacing: NotRequired[Nullable[float]]
    vertical_align: NotRequired[Nullable[FieldGetTemplateFieldVerticalAlign1]]


class FieldGetTemplateFieldFieldMetaText(BaseModel):
    type: FieldGetTemplateFieldTypeText

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text: Optional[str] = None

    character_limit: Annotated[
        Optional[float], pydantic.Field(alias="characterLimit")
    ] = None

    text_align: Annotated[
        Optional[FieldGetTemplateFieldTextAlign5], pydantic.Field(alias="textAlign")
    ] = None

    line_height: Annotated[
        OptionalNullable[float], pydantic.Field(alias="lineHeight")
    ] = UNSET

    letter_spacing: Annotated[
        OptionalNullable[float], pydantic.Field(alias="letterSpacing")
    ] = UNSET

    vertical_align: Annotated[
        OptionalNullable[FieldGetTemplateFieldVerticalAlign1],
        pydantic.Field(alias="verticalAlign"),
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "label",
            "placeholder",
            "required",
            "readOnly",
            "fontSize",
            "text",
            "characterLimit",
            "textAlign",
            "lineHeight",
            "letterSpacing",
            "verticalAlign",
        ]
        nullable_fields = ["lineHeight", "letterSpacing", "verticalAlign"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class FieldGetTemplateFieldTypeDate(str, Enum):
    DATE = "date"


class FieldGetTemplateFieldTextAlign4(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class FieldGetTemplateFieldFieldMetaDateTypedDict(TypedDict):
    type: FieldGetTemplateFieldTypeDate
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text_align: NotRequired[FieldGetTemplateFieldTextAlign4]


class FieldGetTemplateFieldFieldMetaDate(BaseModel):
    type: FieldGetTemplateFieldTypeDate

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text_align: Annotated[
        Optional[FieldGetTemplateFieldTextAlign4], pydantic.Field(alias="textAlign")
    ] = None


class FieldGetTemplateFieldTypeEmail(str, Enum):
    EMAIL = "email"


class FieldGetTemplateFieldTextAlign3(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class FieldGetTemplateFieldFieldMetaEmailTypedDict(TypedDict):
    type: FieldGetTemplateFieldTypeEmail
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text_align: NotRequired[FieldGetTemplateFieldTextAlign3]


class FieldGetTemplateFieldFieldMetaEmail(BaseModel):
    type: FieldGetTemplateFieldTypeEmail

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text_align: Annotated[
        Optional[FieldGetTemplateFieldTextAlign3], pydantic.Field(alias="textAlign")
    ] = None


class FieldGetTemplateFieldTypeName(str, Enum):
    NAME = "name"


class FieldGetTemplateFieldTextAlign2(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class FieldGetTemplateFieldFieldMetaNameTypedDict(TypedDict):
    type: FieldGetTemplateFieldTypeName
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text_align: NotRequired[FieldGetTemplateFieldTextAlign2]


class FieldGetTemplateFieldFieldMetaName(BaseModel):
    type: FieldGetTemplateFieldTypeName

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text_align: Annotated[
        Optional[FieldGetTemplateFieldTextAlign2], pydantic.Field(alias="textAlign")
    ] = None


class FieldGetTemplateFieldTypeInitials(str, Enum):
    INITIALS = "initials"


class FieldGetTemplateFieldTextAlign1(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class FieldGetTemplateFieldFieldMetaInitialsTypedDict(TypedDict):
    type: FieldGetTemplateFieldTypeInitials
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text_align: NotRequired[FieldGetTemplateFieldTextAlign1]


class FieldGetTemplateFieldFieldMetaInitials(BaseModel):
    type: FieldGetTemplateFieldTypeInitials

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text_align: Annotated[
        Optional[FieldGetTemplateFieldTextAlign1], pydantic.Field(alias="textAlign")
    ] = None


class FieldGetTemplateFieldTypeSignature(str, Enum):
    SIGNATURE = "signature"


class FieldGetTemplateFieldFieldMetaSignatureTypedDict(TypedDict):
    type: FieldGetTemplateFieldTypeSignature
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]


class FieldGetTemplateFieldFieldMetaSignature(BaseModel):
    type: FieldGetTemplateFieldTypeSignature

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12


FieldGetTemplateFieldFieldMetaUnionTypedDict = TypeAliasType(
    "FieldGetTemplateFieldFieldMetaUnionTypedDict",
    Union[
        FieldGetTemplateFieldFieldMetaSignatureTypedDict,
        FieldGetTemplateFieldFieldMetaInitialsTypedDict,
        FieldGetTemplateFieldFieldMetaNameTypedDict,
        FieldGetTemplateFieldFieldMetaEmailTypedDict,
        FieldGetTemplateFieldFieldMetaDateTypedDict,
        FieldGetTemplateFieldFieldMetaRadioTypedDict,
        FieldGetTemplateFieldFieldMetaDropdownTypedDict,
        FieldGetTemplateFieldFieldMetaCheckboxTypedDict,
        FieldGetTemplateFieldFieldMetaTextTypedDict,
        FieldGetTemplateFieldFieldMetaNumberTypedDict,
    ],
)


FieldGetTemplateFieldFieldMetaUnion = TypeAliasType(
    "FieldGetTemplateFieldFieldMetaUnion",
    Union[
        FieldGetTemplateFieldFieldMetaSignature,
        FieldGetTemplateFieldFieldMetaInitials,
        FieldGetTemplateFieldFieldMetaName,
        FieldGetTemplateFieldFieldMetaEmail,
        FieldGetTemplateFieldFieldMetaDate,
        FieldGetTemplateFieldFieldMetaRadio,
        FieldGetTemplateFieldFieldMetaDropdown,
        FieldGetTemplateFieldFieldMetaCheckbox,
        FieldGetTemplateFieldFieldMetaText,
        FieldGetTemplateFieldFieldMetaNumber,
    ],
)


class FieldGetTemplateFieldResponseTypedDict(TypedDict):
    r"""Successful response"""

    envelope_id: str
    envelope_item_id: str
    type: FieldGetTemplateFieldType
    id: float
    secondary_id: str
    recipient_id: float
    page: float
    position_x: Any
    position_y: Any
    width: Any
    height: Any
    custom_text: str
    inserted: bool
    field_meta: Nullable[FieldGetTemplateFieldFieldMetaUnionTypedDict]
    document_id: NotRequired[Nullable[float]]
    template_id: NotRequired[Nullable[float]]


class FieldGetTemplateFieldResponse(BaseModel):
    r"""Successful response"""

    envelope_id: Annotated[str, pydantic.Field(alias="envelopeId")]

    envelope_item_id: Annotated[str, pydantic.Field(alias="envelopeItemId")]

    type: FieldGetTemplateFieldType

    id: float

    secondary_id: Annotated[str, pydantic.Field(alias="secondaryId")]

    recipient_id: Annotated[float, pydantic.Field(alias="recipientId")]

    page: float

    position_x: Annotated[Any, pydantic.Field(alias="positionX")]

    position_y: Annotated[Any, pydantic.Field(alias="positionY")]

    width: Any

    height: Any

    custom_text: Annotated[str, pydantic.Field(alias="customText")]

    inserted: bool

    field_meta: Annotated[
        Nullable[FieldGetTemplateFieldFieldMetaUnion], pydantic.Field(alias="fieldMeta")
    ]

    document_id: Annotated[
        OptionalNullable[float], pydantic.Field(alias="documentId")
    ] = UNSET

    template_id: Annotated[
        OptionalNullable[float], pydantic.Field(alias="templateId")
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["documentId", "templateId"]
        nullable_fields = ["fieldMeta", "documentId", "templateId"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
from documenso_sdk.models import DocumensoError
from documenso_sdk.types import BaseModel
import httpx
from typing import List, Optional
from typing_extensions import TypedDict


class DocumentAttachmentUpdateDataTypedDict(TypedDict):
    label: str
    data: str


class DocumentAttachmentUpdateData(BaseModel):
    label: str

    data: str


class DocumentAttachmentUpdateRequestTypedDict(TypedDict):
    id: str
    data: DocumentAttachmentUpdateDataTypedDict


class DocumentAttachmentUpdateRequest(BaseModel):
    id: str

    data: DocumentAttachmentUpdateData


class DocumentAttachmentUpdateInternalServerErrorIssueTypedDict(TypedDict):
    message: str


class DocumentAttachmentUpdateInternalServerErrorIssue(BaseModel):
    message: str


class DocumentAttachmentUpdateInternalServerErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[DocumentAttachmentUpdateInternalServerErrorIssue]] = None


@dataclass(unsafe_hash=True)
class DocumentAttachmentUpdateInternalServerError(DocumensoError):
    r"""Internal server error"""

    data: DocumentAttachmentUpdateInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: DocumentAttachmentUpdateInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DocumentAttachmentUpdateForbiddenIssueTypedDict(TypedDict):
    message: str


class DocumentAttachmentUpdateForbiddenIssue(BaseModel):
    message: str


class DocumentAttachmentUpdateForbiddenErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[DocumentAttachmentUpdateForbiddenIssue]] = None


@dataclass(unsafe_hash=True)
class DocumentAttachmentUpdateForbiddenError(DocumensoError):
    r"""Insufficient access"""

    data: DocumentAttachmentUpdateForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: DocumentAttachmentUpdateForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DocumentAttachmentUpdateUnauthorizedIssueTypedDict(TypedDict):
    message: str


class DocumentAttachmentUpdateUnauthorizedIssue(BaseModel):
    message: str


class DocumentAttachmentUpdateUnauthorizedErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[DocumentAttachmentUpdateUnauthorizedIssue]] = None


@dataclass(unsafe_hash=True)
class DocumentAttachmentUpdateUnauthorizedError(DocumensoError):
    r"""Authorization not provided"""

    data: DocumentAttachmentUpdateUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: DocumentAttachmentUpdateUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DocumentAttachmentUpdateBadRequestIssueTypedDict(TypedDict):
    message: str


class DocumentAttachmentUpdateBadRequestIssue(BaseModel):
    message: str


class DocumentAttachmentUpdateBadRequestErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[DocumentAttachmentUpdateBadRequestIssue]] = None


@dataclass(unsafe_hash=True)
class DocumentAttachmentUpdateBadRequestError(DocumensoError):
    r"""Invalid input data"""

    data: DocumentAttachmentUpdateBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: DocumentAttachmentUpdateBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DocumentAttachmentUpdateResponseTypedDict(TypedDict):
    r"""Successful response"""

    success: bool


class DocumentAttachmentUpdateResponse(BaseModel):
    r"""Successful response"""

    success: bool



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
from documenso_sdk.models import DocumensoError
from documenso_sdk.types import BaseModel
from documenso_sdk.utils import FieldMetadata, PathParamMetadata, QueryParamMetadata
from enum import Enum
import httpx
import pydantic
from typing import Any, Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class EnvelopeItemDownloadVersion(str, Enum):
    r"""The version of the envelope item to download. \"signed\" returns the completed document with signatures, \"original\" returns the original uploaded document."""

    ORIGINAL = "original"
    SIGNED = "signed"


class EnvelopeItemDownloadRequestTypedDict(TypedDict):
    envelope_item_id: str
    r"""The ID of the envelope item to download."""
    version: NotRequired[EnvelopeItemDownloadVersion]
    r"""The version of the envelope item to download. \"signed\" returns the completed document with signatures, \"original\" returns the original uploaded document."""


class EnvelopeItemDownloadRequest(BaseModel):
    envelope_item_id: Annotated[
        str,
        pydantic.Field(alias="envelopeItemId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""The ID of the envelope item to download."""

    version: Annotated[
        Optional[EnvelopeItemDownloadVersion],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = EnvelopeItemDownloadVersion.SIGNED
    r"""The version of the envelope item to download. \"signed\" returns the completed document with signatures, \"original\" returns the original uploaded document."""


class EnvelopeItemDownloadInternalServerErrorIssueTypedDict(TypedDict):
    message: str


class EnvelopeItemDownloadInternalServerErrorIssue(BaseModel):
    message: str


class EnvelopeItemDownloadInternalServerErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[EnvelopeItemDownloadInternalServerErrorIssue]] = None


@dataclass(unsafe_hash=True)
class EnvelopeItemDownloadInternalServerError(DocumensoError):
    r"""Internal server error"""

    data: EnvelopeItemDownloadInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: EnvelopeItemDownloadInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class EnvelopeItemDownloadNotFoundIssueTypedDict(TypedDict):
    message: str


class EnvelopeItemDownloadNotFoundIssue(BaseModel):
    message: str


class EnvelopeItemDownloadNotFoundErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[EnvelopeItemDownloadNotFoundIssue]] = None


@dataclass(unsafe_hash=True)
class EnvelopeItemDownloadNotFoundError(DocumensoError):
    r"""Not found"""

    data: EnvelopeItemDownloadNotFoundErrorData = field(hash=False)

    def __init__(
        self,
        data: EnvelopeItemDownloadNotFoundErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class EnvelopeItemDownloadForbiddenIssueTypedDict(TypedDict):
    message: str


class EnvelopeItemDownloadForbiddenIssue(BaseModel):
    message: str


class EnvelopeItemDownloadForbiddenErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[EnvelopeItemDownloadForbiddenIssue]] = None


@dataclass(unsafe_hash=True)
class EnvelopeItemDownloadForbiddenError(DocumensoError):
    r"""Insufficient access"""

    data: EnvelopeItemDownloadForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: EnvelopeItemDownloadForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class EnvelopeItemDownloadUnauthorizedIssueTypedDict(TypedDict):
    message: str


class EnvelopeItemDownloadUnauthorizedIssue(BaseModel):
    message: str


class EnvelopeItemDownloadUnauthorizedErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[EnvelopeItemDownloadUnauthorizedIssue]] = None


@dataclass(unsafe_hash=True)
class EnvelopeItemDownloadUnauthorizedError(DocumensoError):
    r"""Authorization not provided"""

    data: EnvelopeItemDownloadUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: EnvelopeItemDownloadUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class EnvelopeItemDownloadBadRequestIssueTypedDict(TypedDict):
    message: str


class EnvelopeItemDownloadBadRequestIssue(BaseModel):
    message: str


class EnvelopeItemDownloadBadRequestErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[EnvelopeItemDownloadBadRequestIssue]] = None


@dataclass(unsafe_hash=True)
class EnvelopeItemDownloadBadRequestError(DocumensoError):
    r"""Invalid input data"""

    data: EnvelopeItemDownloadBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: EnvelopeItemDownloadBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class EnvelopeItemDownloadResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: Any


class EnvelopeItemDownloadResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: Any



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
from documenso_sdk.models import DocumensoError
from documenso_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from enum import Enum
import httpx
import pydantic
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class RecipientCreateDocumentRecipientRoleRequest(str, Enum):
    CC = "CC"
    SIGNER = "SIGNER"
    VIEWER = "VIEWER"
    APPROVER = "APPROVER"
    ASSISTANT = "ASSISTANT"


class RecipientCreateDocumentRecipientAccessAuthRequest(str, Enum):
    ACCOUNT = "ACCOUNT"
    TWO_FACTOR_AUTH = "TWO_FACTOR_AUTH"


class RecipientCreateDocumentRecipientActionAuthRequest(str, Enum):
    ACCOUNT = "ACCOUNT"
    PASSKEY = "PASSKEY"
    TWO_FACTOR_AUTH = "TWO_FACTOR_AUTH"
    PASSWORD = "PASSWORD"
    EXPLICIT_NONE = "EXPLICIT_NONE"


class RecipientCreateDocumentRecipientRecipientTypedDict(TypedDict):
    email: str
    name: str
    role: RecipientCreateDocumentRecipientRoleRequest
    signing_order: NotRequired[float]
    access_auth: NotRequired[List[RecipientCreateDocumentRecipientAccessAuthRequest]]
    action_auth: NotRequired[List[RecipientCreateDocumentRecipientActionAuthRequest]]


class RecipientCreateDocumentRecipientRecipient(BaseModel):
    email: str

    name: str

    role: RecipientCreateDocumentRecipientRoleRequest

    signing_order: Annotated[Optional[float], pydantic.Field(alias="signingOrder")] = (
        None
    )

    access_auth: Annotated[
        Optional[List[RecipientCreateDocumentRecipientAccessAuthRequest]],
        pydantic.Field(alias="accessAuth"),
    ] = None

    action_auth: Annotated[
        Optional[List[RecipientCreateDocumentRecipientActionAuthRequest]],
        pydantic.Field(alias="actionAuth"),
    ] = None


class RecipientCreateDocumentRecipientRequestTypedDict(TypedDict):
    document_id: float
    recipient: RecipientCreateDocumentRecipientRecipientTypedDict


class RecipientCreateDocumentRecipientRequest(BaseModel):
    document_id: Annotated[float, pydantic.Field(alias="documentId")]

    recipient: RecipientCreateDocumentRecipientRecipient


class RecipientCreateDocumentRecipientInternalServerErrorIssueTypedDict(TypedDict):
    message: str


class RecipientCreateDocumentRecipientInternalServerErrorIssue(BaseModel):
    message: str


class RecipientCreateDocumentRecipientInternalServerErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[RecipientCreateDocumentRecipientInternalServerErrorIssue]] = (
        None
    )


@dataclass(unsafe_hash=True)
class RecipientCreateDocumentRecipientInternalServerError(DocumensoError):
    r"""Internal server error"""

    data: RecipientCreateDocumentRecipientInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: RecipientCreateDocumentRecipientInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class RecipientCreateDocumentRecipientForbiddenIssueTypedDict(TypedDict):
    message: str


class RecipientCreateDocumentRecipientForbiddenIssue(BaseModel):
    message: str


class RecipientCreateDocumentRecipientForbiddenErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[RecipientCreateDocumentRecipientForbiddenIssue]] = None


@dataclass(unsafe_hash=True)
class RecipientCreateDocumentRecipientForbiddenError(DocumensoError):
    r"""Insufficient access"""

    data: RecipientCreateDocumentRecipientForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: RecipientCreateDocumentRecipientForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class RecipientCreateDocumentRecipientUnauthorizedIssueTypedDict(TypedDict):
    message: str


class RecipientCreateDocumentRecipientUnauthorizedIssue(BaseModel):
    message: str


class RecipientCreateDocumentRecipientUnauthorizedErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[RecipientCreateDocumentRecipientUnauthorizedIssue]] = None


@dataclass(unsafe_hash=True)
class RecipientCreateDocumentRecipientUnauthorizedError(DocumensoError):
    r"""Authorization not provided"""

    data: RecipientCreateDocumentRecipientUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: RecipientCreateDocumentRecipientUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class RecipientCreateDocumentRecipientBadRequestIssueTypedDict(TypedDict):
    message: str


class RecipientCreateDocumentRecipientBadRequestIssue(BaseModel):
    message: str


class RecipientCreateDocumentRecipientBadRequestErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[RecipientCreateDocumentRecipientBadRequestIssue]] = None


@dataclass(unsafe_hash=True)
class RecipientCreateDocumentRecipientBadRequestError(DocumensoError):
    r"""Invalid input data"""

    data: RecipientCreateDocumentRecipientBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: RecipientCreateDocumentRecipientBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class RecipientCreateDocumentRecipientRoleResponse(str, Enum):
    CC = "CC"
    SIGNER = "SIGNER"
    VIEWER = "VIEWER"
    APPROVER = "APPROVER"
    ASSISTANT = "ASSISTANT"


class RecipientCreateDocumentRecipientReadStatus(str, Enum):
    NOT_OPENED = "NOT_OPENED"
    OPENED = "OPENED"


class RecipientCreateDocumentRecipientSigningStatus(str, Enum):
    NOT_SIGNED = "NOT_SIGNED"
    SIGNED = "SIGNED"
    REJECTED = "REJECTED"


class RecipientCreateDocumentRecipientSendStatus(str, Enum):
    NOT_SENT = "NOT_SENT"
    SENT = "SENT"


class RecipientCreateDocumentRecipientAccessAuthResponse(str, Enum):
    ACCOUNT = "ACCOUNT"
    TWO_FACTOR_AUTH = "TWO_FACTOR_AUTH"


class RecipientCreateDocumentRecipientActionAuthResponse(str, Enum):
    ACCOUNT = "ACCOUNT"
    PASSKEY = "PASSKEY"
    TWO_FACTOR_AUTH = "TWO_FACTOR_AUTH"
    PASSWORD = "PASSWORD"
    EXPLICIT_NONE = "EXPLICIT_NONE"


class RecipientCreateDocumentRecipientAuthOptionsTypedDict(TypedDict):
    access_auth: List[RecipientCreateDocumentRecipientAccessAuthResponse]
    action_auth: List[RecipientCreateDocumentRecipientActionAuthResponse]


class RecipientCreateDocumentRecipientAuthOptions(BaseModel):
    access_auth: Annotated[
        List[RecipientCreateDocumentRecipientAccessAuthResponse],
        pydantic.Field(alias="accessAuth"),
    ]

    action_auth: Annotated[
        List[RecipientCreateDocumentRecipientActionAuthResponse],
        pydantic.Field(alias="actionAuth"),
    ]


class RecipientCreateDocumentRecipientResponseTypedDict(TypedDict):
    r"""Successful response"""

    envelope_id: str
    role: RecipientCreateDocumentRecipientRoleResponse
    read_status: RecipientCreateDocumentRecipientReadStatus
    signing_status: RecipientCreateDocumentRecipientSigningStatus
    send_status: RecipientCreateDocumentRecipientSendStatus
    id: float
    email: str
    name: str
    token: str
    document_deleted_at: Nullable[str]
    expired: Nullable[str]
    signed_at: Nullable[str]
    auth_options: Nullable[RecipientCreateDocumentRecipientAuthOptionsTypedDict]
    signing_order: Nullable[float]
    rejection_reason: Nullable[str]
    document_id: NotRequired[Nullable[float]]
    template_id: NotRequired[Nullable[float]]


class RecipientCreateDocumentRecipientResponse(BaseModel):
    r"""Successful response"""

    envelope_id: Annotated[str, pydantic.Field(alias="envelopeId")]

    role: RecipientCreateDocumentRecipientRoleResponse

    read_status: Annotated[
        RecipientCreateDocumentRecipientReadStatus, pydantic.Field(alias="readStatus")
    ]

    signing_status: Annotated[
        RecipientCreateDocumentRecipientSigningStatus,
        pydantic.Field(alias="signingStatus"),
    ]

    send_status: Annotated[
        RecipientCreateDocumentRecipientSendStatus, pydantic.Field(alias="sendStatus")
    ]

    id: float

    email: str

    name: str

    token: str

    document_deleted_at: Annotated[
        Nullable[str], pydantic.Field(alias="documentDeletedAt")
    ]

    expired: Nullable[str]

    signed_at: Annotated[Nullable[str], pydantic.Field(alias="signedAt")]

    auth_options: Annotated[
        Nullable[RecipientCreateDocumentRecipientAuthOptions],
        pydantic.Field(alias="authOptions"),
    ]

    signing_order: Annotated[Nullable[float], pydantic.Field(alias="signingOrder")]

    rejection_reason: Annotated[Nullable[str], pydantic.Field(alias="rejectionReason")]

    document_id: Annotated[
        OptionalNullable[float], pydantic.Field(alias="documentId")
    ] = UNSET

    template_id: Annotated[
        OptionalNullable[float], pydantic.Field(alias="templateId")
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["documentId", "templateId"]
        nullable_fields = [
            "documentDeletedAt",
            "expired",
            "signedAt",
            "authOptions",
            "signingOrder",
            "rejectionReason",
            "documentId",
            "templateId",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
from documenso_sdk.models import DocumensoError
from documenso_sdk.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from enum import Enum
import httpx
import pydantic
from pydantic import model_serializer
from typing import Any, List, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


class FieldUpdateTemplateFieldTypeDropdownRequest1(str, Enum):
    DROPDOWN = "DROPDOWN"


class FieldUpdateTemplateFieldTypeDropdownRequest2(str, Enum):
    DROPDOWN = "dropdown"


class FieldUpdateTemplateFieldValueDropdownTypedDict(TypedDict):
    value: str


class FieldUpdateTemplateFieldValueDropdown(BaseModel):
    value: str


class FieldUpdateTemplateFieldFieldMetaDropdownRequestTypedDict(TypedDict):
    type: FieldUpdateTemplateFieldTypeDropdownRequest2
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    values: NotRequired[List[FieldUpdateTemplateFieldValueDropdownTypedDict]]
    default_value: NotRequired[str]


class FieldUpdateTemplateFieldFieldMetaDropdownRequest(BaseModel):
    type: FieldUpdateTemplateFieldTypeDropdownRequest2

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    values: Optional[List[FieldUpdateTemplateFieldValueDropdown]] = None

    default_value: Annotated[Optional[str], pydantic.Field(alias="defaultValue")] = None


class FieldUpdateTemplateFieldFieldDropdownTypedDict(TypedDict):
    type: FieldUpdateTemplateFieldTypeDropdownRequest1
    id: float
    field_meta: NotRequired[FieldUpdateTemplateFieldFieldMetaDropdownRequestTypedDict]
    page_number: NotRequired[float]
    page_x: NotRequired[float]
    page_y: NotRequired[float]
    width: NotRequired[float]
    height: NotRequired[float]


class FieldUpdateTemplateFieldFieldDropdown(BaseModel):
    type: FieldUpdateTemplateFieldTypeDropdownRequest1

    id: float

    field_meta: Annotated[
        Optional[FieldUpdateTemplateFieldFieldMetaDropdownRequest],
        pydantic.Field(alias="fieldMeta"),
    ] = None

    page_number: Annotated[Optional[float], pydantic.Field(alias="pageNumber")] = None

    page_x: Annotated[Optional[float], pydantic.Field(alias="pageX")] = None

    page_y: Annotated[Optional[float], pydantic.Field(alias="pageY")] = None

    width: Optional[float] = None

    height: Optional[float] = None


class FieldUpdateTemplateFieldTypeCheckboxRequest1(str, Enum):
    CHECKBOX = "CHECKBOX"


class FieldUpdateTemplateFieldTypeCheckboxRequest2(str, Enum):
    CHECKBOX = "checkbox"


class FieldUpdateTemplateFieldValueCheckboxTypedDict(TypedDict):
    id: float
    checked: bool
    value: str


class FieldUpdateTemplateFieldValueCheckbox(BaseModel):
    id: float

    checked: bool

    value: str


class FieldUpdateTemplateFieldDirectionCheckbox(str, Enum):
    VERTICAL = "vertical"
    HORIZONTAL = "horizontal"


class FieldUpdateTemplateFieldFieldMetaCheckboxRequestTypedDict(TypedDict):
    type: FieldUpdateTemplateFieldTypeCheckboxRequest2
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    values: NotRequired[List[FieldUpdateTemplateFieldValueCheckboxTypedDict]]
    validation_rule: NotRequired[str]
    validation_length: NotRequired[float]
    direction: NotRequired[FieldUpdateTemplateFieldDirectionCheckbox]


class FieldUpdateTemplateFieldFieldMetaCheckboxRequest(BaseModel):
    type: FieldUpdateTemplateFieldTypeCheckboxRequest2

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    values: Optional[List[FieldUpdateTemplateFieldValueCheckbox]] = None

    validation_rule: Annotated[
        Optional[str], pydantic.Field(alias="validationRule")
    ] = None

    validation_length: Annotated[
        Optional[float], pydantic.Field(alias="validationLength")
    ] = None

    direction: Optional[FieldUpdateTemplateFieldDirectionCheckbox] = (
        FieldUpdateTemplateFieldDirectionCheckbox.VERTICAL
    )


class FieldUpdateTemplateFieldFieldCheckboxTypedDict(TypedDict):
    type: FieldUpdateTemplateFieldTypeCheckboxRequest1
    id: float
    field_meta: NotRequired[FieldUpdateTemplateFieldFieldMetaCheckboxRequestTypedDict]
    page_number: NotRequired[float]
    page_x: NotRequired[float]
    page_y: NotRequired[float]
    width: NotRequired[float]
    height: NotRequired[float]


class FieldUpdateTemplateFieldFieldCheckbox(BaseModel):
    type: FieldUpdateTemplateFieldTypeCheckboxRequest1

    id: float

    field_meta: Annotated[
        Optional[FieldUpdateTemplateFieldFieldMetaCheckboxRequest],
        pydantic.Field(alias="fieldMeta"),
    ] = None

    page_number: Annotated[Optional[float], pydantic.Field(alias="pageNumber")] = None

    page_x: Annotated[Optional[float], pydantic.Field(alias="pageX")] = None

    page_y: Annotated[Optional[float], pydantic.Field(alias="pageY")] = None

    width: Optional[float] = None

    height: Optional[float] = None


class FieldUpdateTemplateFieldTypeRadioRequest1(str, Enum):
    RADIO = "RADIO"


class FieldUpdateTemplateFieldTypeRadioRequest2(str, Enum):
    RADIO = "radio"


class FieldUpdateTemplateFieldValueRadioTypedDict(TypedDict):
    id: float
    checked: bool
    value: str


class FieldUpdateTemplateFieldValueRadio(BaseModel):
    id: float

    checked: bool

    value: str


class FieldUpdateTemplateFieldDirectionRadio(str, Enum):
    VERTICAL = "vertical"
    HORIZONTAL = "horizontal"


class FieldUpdateTemplateFieldFieldMetaRadioRequestTypedDict(TypedDict):
    type: FieldUpdateTemplateFieldTypeRadioRequest2
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    values: NotRequired[List[FieldUpdateTemplateFieldValueRadioTypedDict]]
    direction: NotRequired[FieldUpdateTemplateFieldDirectionRadio]


class FieldUpdateTemplateFieldFieldMetaRadioRequest(BaseModel):
    type: FieldUpdateTemplateFieldTypeRadioRequest2

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    values: Optional[List[FieldUpdateTemplateFieldValueRadio]] = None

    direction: Optional[FieldUpdateTemplateFieldDirectionRadio] = (
        FieldUpdateTemplateFieldDirectionRadio.VERTICAL
    )


class FieldUpdateTemplateFieldFieldRadioTypedDict(TypedDict):
    type: FieldUpdateTemplateFieldTypeRadioRequest1
    id: float
    field_meta: NotRequired[FieldUpdateTemplateFieldFieldMetaRadioRequestTypedDict]
    page_number: NotRequired[float]
    page_x: NotRequired[float]
    page_y: NotRequired[float]
    width: NotRequired[float]
    height: NotRequired[float]


class FieldUpdateTemplateFieldFieldRadio(BaseModel):
    type: FieldUpdateTemplateFieldTypeRadioRequest1

    id: float

    field_meta: Annotated[
        Optional[FieldUpdateTemplateFieldFieldMetaRadioRequest],
        pydantic.Field(alias="fieldMeta"),
    ] = None

    page_number: Annotated[Optional[float], pydantic.Field(alias="pageNumber")] = None

    page_x: Annotated[Optional[float], pydantic.Field(alias="pageX")] = None

    page_y: Annotated[Optional[float], pydantic.Field(alias="pageY")] = None

    width: Optional[float] = None

    height: Optional[float] = None


class FieldUpdateTemplateFieldTypeNumberRequest1(str, Enum):
    NUMBER = "NUMBER"


class FieldUpdateTemplateFieldTypeNumberRequest2(str, Enum):
    NUMBER = "number"


class FieldUpdateTemplateFieldTextAlignNumber(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class FieldUpdateTemplateFieldVerticalAlignNumber(str, Enum):
    TOP = "top"
    MIDDLE = "middle"
    BOTTOM = "bottom"


class FieldUpdateTemplateFieldFieldMetaNumberRequestTypedDict(TypedDict):
    type: FieldUpdateTemplateFieldTypeNumberRequest2
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    number_format: NotRequired[Nullable[str]]
    value: NotRequired[str]
    min_value: NotRequired[Nullable[float]]
    max_value: NotRequired[Nullable[float]]
    text_align: NotRequired[FieldUpdateTemplateFieldTextAlignNumber]
    line_height: NotRequired[Nullable[float]]
    letter_spacing: NotRequired[Nullable[float]]
    vertical_align: NotRequired[Nullable[FieldUpdateTemplateFieldVerticalAlignNumber]]


class FieldUpdateTemplateFieldFieldMetaNumberRequest(BaseModel):
    type: FieldUpdateTemplateFieldTypeNumberRequest2

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    number_format: Annotated[
        OptionalNullable[str], pydantic.Field(alias="numberFormat")
    ] = UNSET

    value: Optional[str] = None

    min_value: Annotated[OptionalNullable[float], pydantic.Field(alias="minValue")] = (
        UNSET
    )

    max_value: Annotated[OptionalNullable[float], pydantic.Field(alias="maxValue")] = (
        UNSET
    )

    text_align: Annotated[
        Optional[FieldUpdateTemplateFieldTextAlignNumber],
        pydantic.Field(alias="textAlign"),
    ] = None

    line_height: Annotated[
        OptionalNullable[float], pydantic.Field(alias="lineHeight")
    ] = UNSET

    letter_spacing: Annotated[
        OptionalNullable[float], pydantic.Field(alias="letterSpacing")
    ] = UNSET

    vertical_align: Annotated[
        OptionalNullable[FieldUpdateTemplateFieldVerticalAlignNumber],
        pydantic.Field(alias="verticalAlign"),
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "label",
            "placeholder",
            "required",
            "readOnly",
            "fontSize",
            "numberFormat",
            "value",
            "minValue",
            "maxValue",
            "textAlign",
            "lineHeight",
            "letterSpacing",
            "verticalAlign",
        ]
        nullable_fields = [
            "numberFormat",
            "minValue",
            "maxValue",
            "lineHeight",
            "letterSpacing",
            "verticalAlign",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class FieldUpdateTemplateFieldFieldNumberTypedDict(TypedDict):
    type: FieldUpdateTemplateFieldTypeNumberRequest1
    id: float
    field_meta: NotRequired[FieldUpdateTemplateFieldFieldMetaNumberRequestTypedDict]
    page_number: NotRequired[float]
    page_x: NotRequired[float]
    page_y: NotRequired[float]
    width: NotRequired[float]
    height: NotRequired[float]


class FieldUpdateTemplateFieldFieldNumber(BaseModel):
    type: FieldUpdateTemplateFieldTypeNumberRequest1

    id: float

    field_meta: Annotated[
        Optional[FieldUpdateTemplateFieldFieldMetaNumberRequest],
        pydantic.Field(alias="fieldMeta"),
    ] = None

    page_number: Annotated[Optional[float], pydantic.Field(alias="pageNumber")] = None

    page_x: Annotated[Optional[float], pydantic.Field(alias="pageX")] = None

    page_y: Annotated[Optional[float], pydantic.Field(alias="pageY")] = None

    width: Optional[float] = None

    height: Optional[float] = None


class FieldUpdateTemplateFieldTypeTextRequest1(str, Enum):
    TEXT = "TEXT"


class FieldUpdateTemplateFieldTypeTextRequest2(str, Enum):
    TEXT = "text"


class FieldUpdateTemplateFieldTextAlignText(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class FieldUpdateTemplateFieldVerticalAlignText(str, Enum):
    TOP = "top"
    MIDDLE = "middle"
    BOTTOM = "bottom"


class FieldUpdateTemplateFieldFieldMetaTextRequestTypedDict(TypedDict):
    type: FieldUpdateTemplateFieldTypeTextRequest2
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text: NotRequired[str]
    character_limit: NotRequired[float]
    text_align: NotRequired[FieldUpdateTemplateFieldTextAlignText]
    line_height: NotRequired[Nullable[float]]
    letter_spacing: NotRequired[Nullable[float]]
    vertical_align: NotRequired[Nullable[FieldUpdateTemplateFieldVerticalAlignText]]


class FieldUpdateTemplateFieldFieldMetaTextRequest(BaseModel):
    type: FieldUpdateTemplateFieldTypeTextRequest2

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text: Optional[str] = None

    character_limit: Annotated[
        Optional[float], pydantic.Field(alias="characterLimit")
    ] = None

    text_align: Annotated[
        Optional[FieldUpdateTemplateFieldTextAlignText],
        pydantic.Field(alias="textAlign"),
    ] = None

    line_height: Annotated[
        OptionalNullable[float], pydantic.Field(alias="lineHeight")
    ] = UNSET

    letter_spacing: Annotated[
        OptionalNullable[float], pydantic.Field(alias="letterSpacing")
    ] = UNSET

    vertical_align: Annotated[
        OptionalNullable[FieldUpdateTemplateFieldVerticalAlignText],
        pydantic.Field(alias="verticalAlign"),
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "label",
            "placeholder",
            "required",
            "readOnly",
            "fontSize",
            "text",
            "characterLimit",
            "textAlign",
            "lineHeight",
            "letterSpacing",
            "verticalAlign",
        ]
        nullable_fields = ["lineHeight", "letterSpacing", "verticalAlign"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class FieldUpdateTemplateFieldFieldTextTypedDict(TypedDict):
    type: FieldUpdateTemplateFieldTypeTextRequest1
    id: float
    field_meta: NotRequired[FieldUpdateTemplateFieldFieldMetaTextRequestTypedDict]
    page_number: NotRequired[float]
    page_x: NotRequired[float]
    page_y: NotRequired[float]
    width: NotRequired[float]
    height: NotRequired[float]


class FieldUpdateTemplateFieldFieldText(BaseModel):
    type: FieldUpdateTemplateFieldTypeTextRequest1

    id: float

    field_meta: Annotated[
        Optional[FieldUpdateTemplateFieldFieldMetaTextRequest],
        pydantic.Field(alias="fieldMeta"),
    ] = None

    page_number: Annotated[Optional[float], pydantic.Field(alias="pageNumber")] = None

    page_x: Annotated[Optional[float], pydantic.Field(alias="pageX")] = None

    page_y: Annotated[Optional[float], pydantic.Field(alias="pageY")] = None

    width: Optional[float] = None

    height: Optional[float] = None


class FieldUpdateTemplateFieldTypeDateRequest1(str, Enum):
    DATE = "DATE"


class FieldUpdateTemplateFieldTypeDateRequest2(str, Enum):
    DATE = "date"


class FieldUpdateTemplateFieldTextAlignDate(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class FieldUpdateTemplateFieldFieldMetaDateRequestTypedDict(TypedDict):
    type: FieldUpdateTemplateFieldTypeDateRequest2
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text_align: NotRequired[FieldUpdateTemplateFieldTextAlignDate]


class FieldUpdateTemplateFieldFieldMetaDateRequest(BaseModel):
    type: FieldUpdateTemplateFieldTypeDateRequest2

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text_align: Annotated[
        Optional[FieldUpdateTemplateFieldTextAlignDate],
        pydantic.Field(alias="textAlign"),
    ] = None


class FieldUpdateTemplateFieldFieldDateTypedDict(TypedDict):
    type: FieldUpdateTemplateFieldTypeDateRequest1
    id: float
    field_meta: NotRequired[FieldUpdateTemplateFieldFieldMetaDateRequestTypedDict]
    page_number: NotRequired[float]
    page_x: NotRequired[float]
    page_y: NotRequired[float]
    width: NotRequired[float]
    height: NotRequired[float]


class FieldUpdateTemplateFieldFieldDate(BaseModel):
    type: FieldUpdateTemplateFieldTypeDateRequest1

    id: float

    field_meta: Annotated[
        Optional[FieldUpdateTemplateFieldFieldMetaDateRequest],
        pydantic.Field(alias="fieldMeta"),
    ] = None

    page_number: Annotated[Optional[float], pydantic.Field(alias="pageNumber")] = None

    page_x: Annotated[Optional[float], pydantic.Field(alias="pageX")] = None

    page_y: Annotated[Optional[float], pydantic.Field(alias="pageY")] = None

    width: Optional[float] = None

    height: Optional[float] = None


class FieldUpdateTemplateFieldTypeEmailRequest1(str, Enum):
    EMAIL = "EMAIL"


class FieldUpdateTemplateFieldTypeEmailRequest2(str, Enum):
    EMAIL = "email"


class FieldUpdateTemplateFieldTextAlignEmail(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class FieldUpdateTemplateFieldFieldMetaEmailRequestTypedDict(TypedDict):
    type: FieldUpdateTemplateFieldTypeEmailRequest2
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text_align: NotRequired[FieldUpdateTemplateFieldTextAlignEmail]


class FieldUpdateTemplateFieldFieldMetaEmailRequest(BaseModel):
    type: FieldUpdateTemplateFieldTypeEmailRequest2

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text_align: Annotated[
        Optional[FieldUpdateTemplateFieldTextAlignEmail],
        pydantic.Field(alias="textAlign"),
    ] = None


class FieldUpdateTemplateFieldFieldEmailTypedDict(TypedDict):
    type: FieldUpdateTemplateFieldTypeEmailRequest1
    id: float
    field_meta: NotRequired[FieldUpdateTemplateFieldFieldMetaEmailRequestTypedDict]
    page_number: NotRequired[float]
    page_x: NotRequired[float]
    page_y: NotRequired[float]
    width: NotRequired[float]
    height: NotRequired[float]


class FieldUpdateTemplateFieldFieldEmail(BaseModel):
    type: FieldUpdateTemplateFieldTypeEmailRequest1

    id: float

    field_meta: Annotated[
        Optional[FieldUpdateTemplateFieldFieldMetaEmailRequest],
        pydantic.Field(alias="fieldMeta"),
    ] = None

    page_number: Annotated[Optional[float], pydantic.Field(alias="pageNumber")] = None

    page_x: Annotated[Optional[float], pydantic.Field(alias="pageX")] = None

    page_y: Annotated[Optional[float], pydantic.Field(alias="pageY")] = None

    width: Optional[float] = None

    height: Optional[float] = None


class FieldUpdateTemplateFieldTypeNameRequest1(str, Enum):
    NAME = "NAME"


class FieldUpdateTemplateFieldTypeNameRequest2(str, Enum):
    NAME = "name"


class FieldUpdateTemplateFieldTextAlignName(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class FieldUpdateTemplateFieldFieldMetaNameRequestTypedDict(TypedDict):
    type: FieldUpdateTemplateFieldTypeNameRequest2
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text_align: NotRequired[FieldUpdateTemplateFieldTextAlignName]


class FieldUpdateTemplateFieldFieldMetaNameRequest(BaseModel):
    type: FieldUpdateTemplateFieldTypeNameRequest2

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text_align: Annotated[
        Optional[FieldUpdateTemplateFieldTextAlignName],
        pydantic.Field(alias="textAlign"),
    ] = None


class FieldUpdateTemplateFieldFieldNameTypedDict(TypedDict):
    type: FieldUpdateTemplateFieldTypeNameRequest1
    id: float
    field_meta: NotRequired[FieldUpdateTemplateFieldFieldMetaNameRequestTypedDict]
    page_number: NotRequired[float]
    page_x: NotRequired[float]
    page_y: NotRequired[float]
    width: NotRequired[float]
    height: NotRequired[float]


class FieldUpdateTemplateFieldFieldName(BaseModel):
    type: FieldUpdateTemplateFieldTypeNameRequest1

    id: float

    field_meta: Annotated[
        Optional[FieldUpdateTemplateFieldFieldMetaNameRequest],
        pydantic.Field(alias="fieldMeta"),
    ] = None

    page_number: Annotated[Optional[float], pydantic.Field(alias="pageNumber")] = None

    page_x: Annotated[Optional[float], pydantic.Field(alias="pageX")] = None

    page_y: Annotated[Optional[float], pydantic.Field(alias="pageY")] = None

    width: Optional[float] = None

    height: Optional[float] = None


class FieldUpdateTemplateFieldTypeInitialsRequest1(str, Enum):
    INITIALS = "INITIALS"


class FieldUpdateTemplateFieldTypeInitialsRequest2(str, Enum):
    INITIALS = "initials"


class FieldUpdateTemplateFieldTextAlignInitials(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class FieldUpdateTemplateFieldFieldMetaInitialsRequestTypedDict(TypedDict):
    type: FieldUpdateTemplateFieldTypeInitialsRequest2
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text_align: NotRequired[FieldUpdateTemplateFieldTextAlignInitials]


class FieldUpdateTemplateFieldFieldMetaInitialsRequest(BaseModel):
    type: FieldUpdateTemplateFieldTypeInitialsRequest2

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text_align: Annotated[
        Optional[FieldUpdateTemplateFieldTextAlignInitials],
        pydantic.Field(alias="textAlign"),
    ] = None


class FieldUpdateTemplateFieldFieldInitialsTypedDict(TypedDict):
    type: FieldUpdateTemplateFieldTypeInitialsRequest1
    id: float
    field_meta: NotRequired[FieldUpdateTemplateFieldFieldMetaInitialsRequestTypedDict]
    page_number: NotRequired[float]
    page_x: NotRequired[float]
    page_y: NotRequired[float]
    width: NotRequired[float]
    height: NotRequired[float]


class FieldUpdateTemplateFieldFieldInitials(BaseModel):
    type: FieldUpdateTemplateFieldTypeInitialsRequest1

    id: float

    field_meta: Annotated[
        Optional[FieldUpdateTemplateFieldFieldMetaInitialsRequest],
        pydantic.Field(alias="fieldMeta"),
    ] = None

    page_number: Annotated[Optional[float], pydantic.Field(alias="pageNumber")] = None

    page_x: Annotated[Optional[float], pydantic.Field(alias="pageX")] = None

    page_y: Annotated[Optional[float], pydantic.Field(alias="pageY")] = None

    width: Optional[float] = None

    height: Optional[float] = None


class FieldUpdateTemplateFieldTypeFreeSignature(str, Enum):
    FREE_SIGNATURE = "FREE_SIGNATURE"


class FieldUpdateTemplateFieldFieldFreeSignatureTypedDict(TypedDict):
    type: FieldUpdateTemplateFieldTypeFreeSignature
    id: float
    page_number: NotRequired[float]
    page_x: NotRequired[float]
    page_y: NotRequired[float]
    width: NotRequired[float]
    height: NotRequired[float]


class FieldUpdateTemplateFieldFieldFreeSignature(BaseModel):
    type: FieldUpdateTemplateFieldTypeFreeSignature

    id: float

    page_number: Annotated[Optional[float], pydantic.Field(alias="pageNumber")] = None

    page_x: Annotated[Optional[float], pydantic.Field(alias="pageX")] = None

    page_y: Annotated[Optional[float], pydantic.Field(alias="pageY")] = None

    width: Optional[float] = None

    height: Optional[float] = None


class FieldUpdateTemplateFieldTypeSignatureRequest1(str, Enum):
    SIGNATURE = "SIGNATURE"


class FieldUpdateTemplateFieldTypeSignatureRequest2(str, Enum):
    SIGNATURE = "signature"


class FieldUpdateTemplateFieldFieldMetaSignatureRequestTypedDict(TypedDict):
    type: FieldUpdateTemplateFieldTypeSignatureRequest2
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]


class FieldUpdateTemplateFieldFieldMetaSignatureRequest(BaseModel):
    type: FieldUpdateTemplateFieldTypeSignatureRequest2

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12


class FieldUpdateTemplateFieldFieldSignatureTypedDict(TypedDict):
    type: FieldUpdateTemplateFieldTypeSignatureRequest1
    id: float
    field_meta: NotRequired[FieldUpdateTemplateFieldFieldMetaSignatureRequestTypedDict]
    page_number: NotRequired[float]
    page_x: NotRequired[float]
    page_y: NotRequired[float]
    width: NotRequired[float]
    height: NotRequired[float]


class FieldUpdateTemplateFieldFieldSignature(BaseModel):
    type: FieldUpdateTemplateFieldTypeSignatureRequest1

    id: float

    field_meta: Annotated[
        Optional[FieldUpdateTemplateFieldFieldMetaSignatureRequest],
        pydantic.Field(alias="fieldMeta"),
    ] = None

    page_number: Annotated[Optional[float], pydantic.Field(alias="pageNumber")] = None

    page_x: Annotated[Optional[float], pydantic.Field(alias="pageX")] = None

    page_y: Annotated[Optional[float], pydantic.Field(alias="pageY")] = None

    width: Optional[float] = None

    height: Optional[float] = None


FieldUpdateTemplateFieldFieldUnionTypedDict = TypeAliasType(
    "FieldUpdateTemplateFieldFieldUnionTypedDict",
    Union[
        FieldUpdateTemplateFieldFieldFreeSignatureTypedDict,
        FieldUpdateTemplateFieldFieldSignatureTypedDict,
        FieldUpdateTemplateFieldFieldInitialsTypedDict,
        FieldUpdateTemplateFieldFieldNameTypedDict,
        FieldUpdateTemplateFieldFieldEmailTypedDict,
        FieldUpdateTemplateFieldFieldDateTypedDict,
        FieldUpdateTemplateFieldFieldTextTypedDict,
        FieldUpdateTemplateFieldFieldNumberTypedDict,
        FieldUpdateTemplateFieldFieldRadioTypedDict,
        FieldUpdateTemplateFieldFieldCheckboxTypedDict,
        FieldUpdateTemplateFieldFieldDropdownTypedDict,
    ],
)


FieldUpdateTemplateFieldFieldUnion = TypeAliasType(
    "FieldUpdateTemplateFieldFieldUnion",
    Union[
        FieldUpdateTemplateFieldFieldFreeSignature,
        FieldUpdateTemplateFieldFieldSignature,
        FieldUpdateTemplateFieldFieldInitials,
        FieldUpdateTemplateFieldFieldName,
        FieldUpdateTemplateFieldFieldEmail,
        FieldUpdateTemplateFieldFieldDate,
        FieldUpdateTemplateFieldFieldText,
        FieldUpdateTemplateFieldFieldNumber,
        FieldUpdateTemplateFieldFieldRadio,
        FieldUpdateTemplateFieldFieldCheckbox,
        FieldUpdateTemplateFieldFieldDropdown,
    ],
)


class FieldUpdateTemplateFieldRequestTypedDict(TypedDict):
    template_id: float
    field: FieldUpdateTemplateFieldFieldUnionTypedDict


class FieldUpdateTemplateFieldRequest(BaseModel):
    template_id: Annotated[float, pydantic.Field(alias="templateId")]

    field: FieldUpdateTemplateFieldFieldUnion


class FieldUpdateTemplateFieldInternalServerErrorIssueTypedDict(TypedDict):
    message: str


class FieldUpdateTemplateFieldInternalServerErrorIssue(BaseModel):
    message: str


class FieldUpdateTemplateFieldInternalServerErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[FieldUpdateTemplateFieldInternalServerErrorIssue]] = None


@dataclass(unsafe_hash=True)
class FieldUpdateTemplateFieldInternalServerError(DocumensoError):
    r"""Internal server error"""

    data: FieldUpdateTemplateFieldInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: FieldUpdateTemplateFieldInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class FieldUpdateTemplateFieldForbiddenIssueTypedDict(TypedDict):
    message: str


class FieldUpdateTemplateFieldForbiddenIssue(BaseModel):
    message: str


class FieldUpdateTemplateFieldForbiddenErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[FieldUpdateTemplateFieldForbiddenIssue]] = None


@dataclass(unsafe_hash=True)
class FieldUpdateTemplateFieldForbiddenError(DocumensoError):
    r"""Insufficient access"""

    data: FieldUpdateTemplateFieldForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: FieldUpdateTemplateFieldForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class FieldUpdateTemplateFieldUnauthorizedIssueTypedDict(TypedDict):
    message: str


class FieldUpdateTemplateFieldUnauthorizedIssue(BaseModel):
    message: str


class FieldUpdateTemplateFieldUnauthorizedErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[FieldUpdateTemplateFieldUnauthorizedIssue]] = None


@dataclass(unsafe_hash=True)
class FieldUpdateTemplateFieldUnauthorizedError(DocumensoError):
    r"""Authorization not provided"""

    data: FieldUpdateTemplateFieldUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: FieldUpdateTemplateFieldUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class FieldUpdateTemplateFieldBadRequestIssueTypedDict(TypedDict):
    message: str


class FieldUpdateTemplateFieldBadRequestIssue(BaseModel):
    message: str


class FieldUpdateTemplateFieldBadRequestErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[FieldUpdateTemplateFieldBadRequestIssue]] = None


@dataclass(unsafe_hash=True)
class FieldUpdateTemplateFieldBadRequestError(DocumensoError):
    r"""Invalid input data"""

    data: FieldUpdateTemplateFieldBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: FieldUpdateTemplateFieldBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class FieldUpdateTemplateFieldTypeResponse(str, Enum):
    SIGNATURE = "SIGNATURE"
    FREE_SIGNATURE = "FREE_SIGNATURE"
    INITIALS = "INITIALS"
    NAME = "NAME"
    EMAIL = "EMAIL"
    DATE = "DATE"
    TEXT = "TEXT"
    NUMBER = "NUMBER"
    RADIO = "RADIO"
    CHECKBOX = "CHECKBOX"
    DROPDOWN = "DROPDOWN"


class FieldUpdateTemplateFieldFieldMetaTypeDropdown(str, Enum):
    DROPDOWN = "dropdown"


class FieldUpdateTemplateFieldValueResponse3TypedDict(TypedDict):
    value: str


class FieldUpdateTemplateFieldValueResponse3(BaseModel):
    value: str


class FieldUpdateTemplateFieldFieldMetaDropdownResponseTypedDict(TypedDict):
    type: FieldUpdateTemplateFieldFieldMetaTypeDropdown
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    values: NotRequired[List[FieldUpdateTemplateFieldValueResponse3TypedDict]]
    default_value: NotRequired[str]


class FieldUpdateTemplateFieldFieldMetaDropdownResponse(BaseModel):
    type: FieldUpdateTemplateFieldFieldMetaTypeDropdown

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    values: Optional[List[FieldUpdateTemplateFieldValueResponse3]] = None

    default_value: Annotated[Optional[str], pydantic.Field(alias="defaultValue")] = None


class FieldUpdateTemplateFieldFieldMetaTypeCheckbox(str, Enum):
    CHECKBOX = "checkbox"


class FieldUpdateTemplateFieldValueResponse2TypedDict(TypedDict):
    id: float
    checked: bool
    value: str


class FieldUpdateTemplateFieldValueResponse2(BaseModel):
    id: float

    checked: bool

    value: str


class FieldUpdateTemplateFieldDirectionResponse2(str, Enum):
    VERTICAL = "vertical"
    HORIZONTAL = "horizontal"


class FieldUpdateTemplateFieldFieldMetaCheckboxResponseTypedDict(TypedDict):
    type: FieldUpdateTemplateFieldFieldMetaTypeCheckbox
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    values: NotRequired[List[FieldUpdateTemplateFieldValueResponse2TypedDict]]
    validation_rule: NotRequired[str]
    validation_length: NotRequired[float]
    direction: NotRequired[FieldUpdateTemplateFieldDirectionResponse2]


class FieldUpdateTemplateFieldFieldMetaCheckboxResponse(BaseModel):
    type: FieldUpdateTemplateFieldFieldMetaTypeCheckbox

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    values: Optional[List[FieldUpdateTemplateFieldValueResponse2]] = None

    validation_rule: Annotated[
        Optional[str], pydantic.Field(alias="validationRule")
    ] = None

    validation_length: Annotated[
        Optional[float], pydantic.Field(alias="validationLength")
    ] = None

    direction: Optional[FieldUpdateTemplateFieldDirectionResponse2] = (
        FieldUpdateTemplateFieldDirectionResponse2.VERTICAL
    )


class FieldUpdateTemplateFieldFieldMetaTypeRadio(str, Enum):
    RADIO = "radio"


class FieldUpdateTemplateFieldValueResponse1TypedDict(TypedDict):
    id: float
    checked: bool
    value: str


class FieldUpdateTemplateFieldValueResponse1(BaseModel):
    id: float

    checked: bool

    value: str


class FieldUpdateTemplateFieldDirectionResponse1(str, Enum):
    VERTICAL = "vertical"
    HORIZONTAL = "horizontal"


class FieldUpdateTemplateFieldFieldMetaRadioResponseTypedDict(TypedDict):
    type: FieldUpdateTemplateFieldFieldMetaTypeRadio
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    values: NotRequired[List[FieldUpdateTemplateFieldValueResponse1TypedDict]]
    direction: NotRequired[FieldUpdateTemplateFieldDirectionResponse1]


class FieldUpdateTemplateFieldFieldMetaRadioResponse(BaseModel):
    type: FieldUpdateTemplateFieldFieldMetaTypeRadio

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    values: Optional[List[FieldUpdateTemplateFieldValueResponse1]] = None

    direction: Optional[FieldUpdateTemplateFieldDirectionResponse1] = (
        FieldUpdateTemplateFieldDirectionResponse1.VERTICAL
    )


class FieldUpdateTemplateFieldFieldMetaTypeNumber(str, Enum):
    NUMBER = "number"


class FieldUpdateTemplateFieldTextAlignResponse6(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class FieldUpdateTemplateFieldVerticalAlignResponse2(str, Enum):
    TOP = "top"
    MIDDLE = "middle"
    BOTTOM = "bottom"


class FieldUpdateTemplateFieldFieldMetaNumberResponseTypedDict(TypedDict):
    type: FieldUpdateTemplateFieldFieldMetaTypeNumber
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    number_format: NotRequired[Nullable[str]]
    value: NotRequired[str]
    min_value: NotRequired[Nullable[float]]
    max_value: NotRequired[Nullable[float]]
    text_align: NotRequired[FieldUpdateTemplateFieldTextAlignResponse6]
    line_height: NotRequired[Nullable[float]]
    letter_spacing: NotRequired[Nullable[float]]
    vertical_align: NotRequired[
        Nullable[FieldUpdateTemplateFieldVerticalAlignResponse2]
    ]


class FieldUpdateTemplateFieldFieldMetaNumberResponse(BaseModel):
    type: FieldUpdateTemplateFieldFieldMetaTypeNumber

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    number_format: Annotated[
        OptionalNullable[str], pydantic.Field(alias="numberFormat")
    ] = UNSET

    value: Optional[str] = None

    min_value: Annotated[OptionalNullable[float], pydantic.Field(alias="minValue")] = (
        UNSET
    )

    max_value: Annotated[OptionalNullable[float], pydantic.Field(alias="maxValue")] = (
        UNSET
    )

    text_align: Annotated[
        Optional[FieldUpdateTemplateFieldTextAlignResponse6],
        pydantic.Field(alias="textAlign"),
    ] = None

    line_height: Annotated[
        OptionalNullable[float], pydantic.Field(alias="lineHeight")
    ] = UNSET

    letter_spacing: Annotated[
        OptionalNullable[float], pydantic.Field(alias="letterSpacing")
    ] = UNSET

    vertical_align: Annotated[
        OptionalNullable[FieldUpdateTemplateFieldVerticalAlignResponse2],
        pydantic.Field(alias="verticalAlign"),
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "label",
            "placeholder",
            "required",
            "readOnly",
            "fontSize",
            "numberFormat",
            "value",
            "minValue",
            "maxValue",
            "textAlign",
            "lineHeight",
            "letterSpacing",
            "verticalAlign",
        ]
        nullable_fields = [
            "numberFormat",
            "minValue",
            "maxValue",
            "lineHeight",
            "letterSpacing",
            "verticalAlign",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class FieldUpdateTemplateFieldFieldMetaTypeText(str, Enum):
    TEXT = "text"


class FieldUpdateTemplateFieldTextAlignResponse5(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class FieldUpdateTemplateFieldVerticalAlignResponse1(str, Enum):
    TOP = "top"
    MIDDLE = "middle"
    BOTTOM = "bottom"


class FieldUpdateTemplateFieldFieldMetaTextResponseTypedDict(TypedDict):
    type: FieldUpdateTemplateFieldFieldMetaTypeText
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text: NotRequired[str]
    character_limit: NotRequired[float]
    text_align: NotRequired[FieldUpdateTemplateFieldTextAlignResponse5]
    line_height: NotRequired[Nullable[float]]
    letter_spacing: NotRequired[Nullable[float]]
    vertical_align: NotRequired[
        Nullable[FieldUpdateTemplateFieldVerticalAlignResponse1]
    ]


class FieldUpdateTemplateFieldFieldMetaTextResponse(BaseModel):
    type: FieldUpdateTemplateFieldFieldMetaTypeText

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text: Optional[str] = None

    character_limit: Annotated[
        Optional[float], pydantic.Field(alias="characterLimit")
    ] = None

    text_align: Annotated[
        Optional[FieldUpdateTemplateFieldTextAlignResponse5],
        pydantic.Field(alias="textAlign"),
    ] = None

    line_height: Annotated[
        OptionalNullable[float], pydantic.Field(alias="lineHeight")
    ] = UNSET

    letter_spacing: Annotated[
        OptionalNullable[float], pydantic.Field(alias="letterSpacing")
    ] = UNSET

    vertical_align: Annotated[
        OptionalNullable[FieldUpdateTemplateFieldVerticalAlignResponse1],
        pydantic.Field(alias="verticalAlign"),
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "label",
            "placeholder",
            "required",
            "readOnly",
            "fontSize",
            "text",
            "characterLimit",
            "textAlign",
            "lineHeight",
            "letterSpacing",
            "verticalAlign",
        ]
        nullable_fields = ["lineHeight", "letterSpacing", "verticalAlign"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class FieldUpdateTemplateFieldFieldMetaTypeDate(str, Enum):
    DATE = "date"


class FieldUpdateTemplateFieldTextAlignResponse4(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class FieldUpdateTemplateFieldFieldMetaDateResponseTypedDict(TypedDict):
    type: FieldUpdateTemplateFieldFieldMetaTypeDate
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text_align: NotRequired[FieldUpdateTemplateFieldTextAlignResponse4]


class FieldUpdateTemplateFieldFieldMetaDateResponse(BaseModel):
    type: FieldUpdateTemplateFieldFieldMetaTypeDate

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text_align: Annotated[
        Optional[FieldUpdateTemplateFieldTextAlignResponse4],
        pydantic.Field(alias="textAlign"),
    ] = None


class FieldUpdateTemplateFieldFieldMetaTypeEmail(str, Enum):
    EMAIL = "email"


class FieldUpdateTemplateFieldTextAlignResponse3(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class FieldUpdateTemplateFieldFieldMetaEmailResponseTypedDict(TypedDict):
    type: FieldUpdateTemplateFieldFieldMetaTypeEmail
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text_align: NotRequired[FieldUpdateTemplateFieldTextAlignResponse3]


class FieldUpdateTemplateFieldFieldMetaEmailResponse(BaseModel):
    type: FieldUpdateTemplateFieldFieldMetaTypeEmail

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text_align: Annotated[
        Optional[FieldUpdateTemplateFieldTextAlignResponse3],
        pydantic.Field(alias="textAlign"),
    ] = None


class FieldUpdateTemplateFieldFieldMetaTypeName(str, Enum):
    NAME = "name"


class FieldUpdateTemplateFieldTextAlignResponse2(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class FieldUpdateTemplateFieldFieldMetaNameResponseTypedDict(TypedDict):
    type: FieldUpdateTemplateFieldFieldMetaTypeName
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text_align: NotRequired[FieldUpdateTemplateFieldTextAlignResponse2]


class FieldUpdateTemplateFieldFieldMetaNameResponse(BaseModel):
    type: FieldUpdateTemplateFieldFieldMetaTypeName

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text_align: Annotated[
        Optional[FieldUpdateTemplateFieldTextAlignResponse2],
        pydantic.Field(alias="textAlign"),
    ] = None


class FieldUpdateTemplateFieldFieldMetaTypeInitials(str, Enum):
    INITIALS = "initials"


class FieldUpdateTemplateFieldTextAlignResponse1(str, Enum):
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"


class FieldUpdateTemplateFieldFieldMetaInitialsResponseTypedDict(TypedDict):
    type: FieldUpdateTemplateFieldFieldMetaTypeInitials
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]
    text_align: NotRequired[FieldUpdateTemplateFieldTextAlignResponse1]


class FieldUpdateTemplateFieldFieldMetaInitialsResponse(BaseModel):
    type: FieldUpdateTemplateFieldFieldMetaTypeInitials

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12

    text_align: Annotated[
        Optional[FieldUpdateTemplateFieldTextAlignResponse1],
        pydantic.Field(alias="textAlign"),
    ] = None


class FieldUpdateTemplateFieldFieldMetaTypeSignature(str, Enum):
    SIGNATURE = "signature"


class FieldUpdateTemplateFieldFieldMetaSignatureResponseTypedDict(TypedDict):
    type: FieldUpdateTemplateFieldFieldMetaTypeSignature
    label: NotRequired[str]
    placeholder: NotRequired[str]
    required: NotRequired[bool]
    read_only: NotRequired[bool]
    font_size: NotRequired[float]


class FieldUpdateTemplateFieldFieldMetaSignatureResponse(BaseModel):
    type: FieldUpdateTemplateFieldFieldMetaTypeSignature

    label: Optional[str] = None

    placeholder: Optional[str] = None

    required: Optional[bool] = None

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = None

    font_size: Annotated[Optional[float], pydantic.Field(alias="fontSize")] = 12


FieldUpdateTemplateFieldFieldMetaUnionTypedDict = TypeAliasType(
    "FieldUpdateTemplateFieldFieldMetaUnionTypedDict",
    Union[
        FieldUpdateTemplateFieldFieldMetaSignatureResponseTypedDict,
        FieldUpdateTemplateFieldFieldMetaInitialsResponseTypedDict,
        FieldUpdateTemplateFieldFieldMetaNameResponseTypedDict,
        FieldUpdateTemplateFieldFieldMetaEmailResponseTypedDict,
        FieldUpdateTemplateFieldFieldMetaDateResponseTypedDict,
        FieldUpdateTemplateFieldFieldMetaRadioResponseTypedDict,
        FieldUpdateTemplateFieldFieldMetaDropdownResponseTypedDict,
        FieldUpdateTemplateFieldFieldMetaCheckboxResponseTypedDict,
        FieldUpdateTemplateFieldFieldMetaTextResponseTypedDict,
        FieldUpdateTemplateFieldFieldMetaNumberResponseTypedDict,
    ],
)


FieldUpdateTemplateFieldFieldMetaUnion = TypeAliasType(
    "FieldUpdateTemplateFieldFieldMetaUnion",
    Union[
        FieldUpdateTemplateFieldFieldMetaSignatureResponse,
        FieldUpdateTemplateFieldFieldMetaInitialsResponse,
        FieldUpdateTemplateFieldFieldMetaNameResponse,
        FieldUpdateTemplateFieldFieldMetaEmailResponse,
        FieldUpdateTemplateFieldFieldMetaDateResponse,
        FieldUpdateTemplateFieldFieldMetaRadioResponse,
        FieldUpdateTemplateFieldFieldMetaDropdownResponse,
        FieldUpdateTemplateFieldFieldMetaCheckboxResponse,
        FieldUpdateTemplateFieldFieldMetaTextResponse,
        FieldUpdateTemplateFieldFieldMetaNumberResponse,
    ],
)


class FieldUpdateTemplateFieldResponseTypedDict(TypedDict):
    r"""Successful response"""

    envelope_id: str
    envelope_item_id: str
    type: FieldUpdateTemplateFieldTypeResponse
    id: float
    secondary_id: str
    recipient_id: float
    page: float
    position_x: Any
    position_y: Any
    width: Any
    height: Any
    custom_text: str
    inserted: bool
    field_meta: Nullable[FieldUpdateTemplateFieldFieldMetaUnionTypedDict]
    document_id: NotRequired[Nullable[float]]
    template_id: NotRequired[Nullable[float]]


class FieldUpdateTemplateFieldResponse(BaseModel):
    r"""Successful response"""

    envelope_id: Annotated[str, pydantic.Field(alias="envelopeId")]

    envelope_item_id: Annotated[str, pydantic.Field(alias="envelopeItemId")]

    type: FieldUpdateTemplateFieldTypeResponse

    id: float

    secondary_id: Annotated[str, pydantic.Field(alias="secondaryId")]

    recipient_id: Annotated[float, pydantic.Field(alias="recipientId")]

    page: float

    position_x: Annotated[Any, pydantic.Field(alias="positionX")]

    position_y: Annotated[Any, pydantic.Field(alias="positionY")]

    width: Any

    height: Any

    custom_text: Annotated[str, pydantic.Field(alias="customText")]

    inserted: bool

    field_meta: Annotated[
        Nullable[FieldUpdateTemplateFieldFieldMetaUnion],
        pydantic.Field(alias="fieldMeta"),
    ]

    document_id: Annotated[
        OptionalNullable[float], pydantic.Field(alias="documentId")
    ] = UNSET

    template_id: Annotated[
        OptionalNullable[float], pydantic.Field(alias="templateId")
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["documentId", "templateId"]
        nullable_fields = ["fieldMeta", "documentId", "templateId"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
from documenso_sdk.models import DocumensoError
from documenso_sdk.types import BaseModel
import httpx
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, TypedDict


class DocumentDuplicateRequestTypedDict(TypedDict):
    document_id: float


class DocumentDuplicateRequest(BaseModel):
    document_id: Annotated[float, pydantic.Field(alias="documentId")]


class DocumentDuplicateInternalServerErrorIssueTypedDict(TypedDict):
    message: str


class DocumentDuplicateInternalServerErrorIssue(BaseModel):
    message: str


class DocumentDuplicateInternalServerErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[DocumentDuplicateInternalServerErrorIssue]] = None


@dataclass(unsafe_hash=True)
class DocumentDuplicateInternalServerError(DocumensoError):
    r"""Internal server error"""

    data: DocumentDuplicateInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: DocumentDuplicateInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DocumentDuplicateForbiddenIssueTypedDict(TypedDict):
    message: str


class DocumentDuplicateForbiddenIssue(BaseModel):
    message: str


class DocumentDuplicateForbiddenErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[DocumentDuplicateForbiddenIssue]] = None


@dataclass(unsafe_hash=True)
class DocumentDuplicateForbiddenError(DocumensoError):
    r"""Insufficient access"""

    data: DocumentDuplicateForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: DocumentDuplicateForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DocumentDuplicateUnauthorizedIssueTypedDict(TypedDict):
    message: str


class DocumentDuplicateUnauthorizedIssue(BaseModel):
    message: str


class DocumentDuplicateUnauthorizedErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[DocumentDuplicateUnauthorizedIssue]] = None


@dataclass(unsafe_hash=True)
class DocumentDuplicateUnauthorizedError(DocumensoError):
    r"""Authorization not provided"""

    data: DocumentDuplicateUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: DocumentDuplicateUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DocumentDuplicateBadRequestIssueTypedDict(TypedDict):
    message: str


class DocumentDuplicateBadRequestIssue(BaseModel):
    message: str


class DocumentDuplicateBadRequestErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[DocumentDuplicateBadRequestIssue]] = None


@dataclass(unsafe_hash=True)
class DocumentDuplicateBadRequestError(DocumensoError):
    r"""Invalid input data"""

    data: DocumentDuplicateBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: DocumentDuplicateBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DocumentDuplicateResponseTypedDict(TypedDict):
    r"""Successful response"""

    id: str
    document_id: float


class DocumentDuplicateResponse(BaseModel):
    r"""Successful response"""

    id: str

    document_id: Annotated[float, pydantic.Field(alias="documentId")]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
from documenso_sdk.models import DocumensoError
from documenso_sdk.types import BaseModel
from documenso_sdk.utils import FieldMetadata, PathParamMetadata, QueryParamMetadata
from enum import Enum
import httpx
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class DocumentDownloadBetaVersion(str, Enum):
    r"""The version of the document to download. \"signed\" returns the completed document with signatures, \"original\" returns the original uploaded document."""

    ORIGINAL = "original"
    SIGNED = "signed"


class DocumentDownloadBetaRequestTypedDict(TypedDict):
    document_id: float
    r"""The ID of the document to download."""
    version: NotRequired[DocumentDownloadBetaVersion]
    r"""The version of the document to download. \"signed\" returns the completed document with signatures, \"original\" returns the original uploaded document."""


class DocumentDownloadBetaRequest(BaseModel):
    document_id: Annotated[
        float,
        pydantic.Field(alias="documentId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""The ID of the document to download."""

    version: Annotated[
        Optional[DocumentDownloadBetaVersion],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = DocumentDownloadBetaVersion.SIGNED
    r"""The version of the document to download. \"signed\" returns the completed document with signatures, \"original\" returns the original uploaded document."""


class DocumentDownloadBetaInternalServerErrorIssueTypedDict(TypedDict):
    message: str


class DocumentDownloadBetaInternalServerErrorIssue(BaseModel):
    message: str


class DocumentDownloadBetaInternalServerErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[DocumentDownloadBetaInternalServerErrorIssue]] = None


@dataclass(unsafe_hash=True)
class DocumentDownloadBetaInternalServerError(DocumensoError):
    r"""Internal server error"""

    data: DocumentDownloadBetaInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: DocumentDownloadBetaInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DocumentDownloadBetaNotFoundIssueTypedDict(TypedDict):
    message: str


class DocumentDownloadBetaNotFoundIssue(BaseModel):
    message: str


class DocumentDownloadBetaNotFoundErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[DocumentDownloadBetaNotFoundIssue]] = None


@dataclass(unsafe_hash=True)
class DocumentDownloadBetaNotFoundError(DocumensoError):
    r"""Not found"""

    data: DocumentDownloadBetaNotFoundErrorData = field(hash=False)

    def __init__(
        self,
        data: DocumentDownloadBetaNotFoundErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DocumentDownloadBetaForbiddenIssueTypedDict(TypedDict):
    message: str


class DocumentDownloadBetaForbiddenIssue(BaseModel):
    message: str


class DocumentDownloadBetaForbiddenErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[DocumentDownloadBetaForbiddenIssue]] = None


@dataclass(unsafe_hash=True)
class DocumentDownloadBetaForbiddenError(DocumensoError):
    r"""Insufficient access"""

    data: DocumentDownloadBetaForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: DocumentDownloadBetaForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DocumentDownloadBetaUnauthorizedIssueTypedDict(TypedDict):
    message: str


class DocumentDownloadBetaUnauthorizedIssue(BaseModel):
    message: str


class DocumentDownloadBetaUnauthorizedErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[DocumentDownloadBetaUnauthorizedIssue]] = None


@dataclass(unsafe_hash=True)
class DocumentDownloadBetaUnauthorizedError(DocumensoError):
    r"""Authorization not provided"""

    data: DocumentDownloadBetaUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: DocumentDownloadBetaUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DocumentDownloadBetaBadRequestIssueTypedDict(TypedDict):
    message: str


class DocumentDownloadBetaBadRequestIssue(BaseModel):
    message: str


class DocumentDownloadBetaBadRequestErrorData(BaseModel):
    message: str

    code: str

    issues: Optional[List[DocumentDownloadBetaBadRequestIssue]] = None


@dataclass(unsafe_hash=True)
class DocumentDownloadBetaBadRequestError(DocumensoError):
    r"""Invalid input data"""

    data: DocumentDownloadBetaBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: DocumentDownloadBetaBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DocumentDownloadBetaResponseTypedDict(TypedDict):
    r"""Successful response"""

    download_url: str
    filename: str
    content_type: str


class DocumentDownloadBetaResponse(BaseModel):
    r"""Successful response"""

    download_url: Annotated[str, pydantic.Field(alias="downloadUrl")]

    filename: str

    content_type: Annotated[str, pydantic.Field(alias="contentType")]
